@@ -5,16 +5,12 @@ association.test <- function(x, Y = x@ped$pheno, X = matrix(1, nrow(x)),
                              tol = .Machine$double.eps^0.25, ...) {
 
   if(beg < 1 || end > ncol(x)) stop("range too wide")
-  if(is.null(x@mu)) stop("Need mu to be set in x")
+  if(is.null(x@mu) | is.null(x@p)) stop("Need p and mu to be set in x (use set.stats)")
   if(length(Y) != nrow(x)) stop("Dimensions of Y and x mismatch")
   
   X <- as.matrix(X)
   if(nrow(X) != nrow(x)) stop("Dimensions of Y and x mismatch")
-  X <- checkX(X, mean(Y))
 
-  response <- match.arg(response)
-  test <- match.arg(test)
-  
   # check dimensions before anything
   n <- nrow(x)
   if(!missing(K)) {
@@ -25,8 +21,26 @@ association.test <- function(x, Y = x@ped$pheno, X = matrix(1, nrow(x)),
       stop("eigenK and x dimensions don't match")
   }
 
-  # random effect
-  if(match.arg(method) == "lmm") { 
+  response <- match.arg(response)
+  test <- match.arg(test)
+  method <- match.arg(method)
+
+  # preparation de X 
+  if(p > 0) {
+    if((method == "lmm" & response == "quantitative" & test == "score") | 
+       (method == "lmm" & response == "binary") |
+       (method == "lm")) { # il faut ajouter les PCs à X
+      X <- cbind(X, eigenK$vectors[,seq_len(p)])
+      X <- trans.X(X, mean.y = mean(Y))
+    } else { 
+      X <- trans.X(X, eigenK$vectors[,seq_len(p)], mean(Y))
+    }
+  } else {
+    X <- trans.X(X, mean.y = mean(Y))
+  }
+
+   # random effect
+  if(method == "lmm") { 
 
     # if(response == "binary" & test != "score") {
     #  warning('Binary phenotype and method = "lmm" force test = "score"')
@@ -52,8 +66,6 @@ association.test <- function(x, Y = x@ped$pheno, X = matrix(1, nrow(x)),
 
     if(response == "quantitative") { # score (argument K), wald ou lrt (eigen K) possibles
       if(test == "score") {
-        if(p > 0) 
-          X <- cbind(X, eigenK$vectors[,seq_len(p)])
         model <- lmm.aireml(Y, X = X, K, get.P = TRUE, ... )
         t <- .Call("gg_GWAS_lmm_score_f", PACKAGE = "gaston", x@bed, model$Py, model$P, x@mu, beg-1, end-1)
         t$p <- pchisq( t$score, df = 1, lower.tail=FALSE)
@@ -67,8 +79,6 @@ association.test <- function(x, Y = x@ped$pheno, X = matrix(1, nrow(x)),
         t$p <- pchisq( t$LRT, df = 1, lower.tail=FALSE)
       }
     } else { # response == "binary", seulement le score test, avec argument K
-      if(p > 0) 
-        X <- cbind(X, eigenK$vectors[,seq_len(p)])
       if(test == "score") {
         model <- logistic.mm.aireml(Y, X = X, K, get.P = TRUE, ... )
         omega <- model$BLUP_omega
@@ -85,29 +95,21 @@ association.test <- function(x, Y = x@ped$pheno, X = matrix(1, nrow(x)),
   }
 
   # only fixed effects
-  if(match.arg(method) == "lm") {
+  if(method == "lm") {
     if(test != "wald") warning('Method = "lm" force test = "wald"')
+    if( any(is.na(Y)) ) 
+      stop("Can't handle missing data in Y")
     if(response == "quantitative") {
-      if( any(is.na(Y)) ) 
-        stop("Can't handle missing data in Y, please recompute eigenK for the individuals with non-missing phenotype")
-      if(p > 0)
-        Q <- qr.Q(qr(cbind(eigenK$vectors[,seq_len(p)], X)))
-      else
-        Q <- qr.Q(qr(X))
-      t <- .Call("gg_GWAS_lm_quanti", PACKAGE = "gaston", x@bed, x@mu, Y, Q, beg-1, end-1);
-      t$p <- pt( abs(t$beta/t$sd), df = length(Y) - ncol(Q) - 1, lower.tail=FALSE)*2
+      t <- .Call("gg_GWAS_lm_quanti", PACKAGE = "gaston", x@bed, x@mu, Y, X, beg-1, end-1);
+      t$p <- pt( abs(t$beta/t$sd), df = length(Y) - ncol(X) - 1, lower.tail=FALSE)*2
     }
     if(response == "binary") {
-      if( any(is.na(Y)) ) 
-        stop("Can't handle missing data in Y, please recompute eigenK for the individuals with non-missing phenotype")
-      if(p > 0) 
-        X <- cbind(X, eigenK$vectors[,seq_len(p)])
       X <- cbind(X,0)
       t <- .Call("gg_GWAS_logit_wald_f", PACKAGE = "gaston", x@bed, x@mu, Y, X, beg-1, end-1, tol);
       t$p <- pchisq( (t$beta/t$sd)**2, df = 1, lower.tail=FALSE)
     }
   }
-  L <- data.frame(chr = x@snps$chr, pos = x@snps$pos, id  = x@snps$id)
+  L <- data.frame(chr = x@snps$chr, pos = x@snps$pos, id = x@snps$id, A1 = x@snps$A1, A2 = x@snps$A2, freqA2 = x@p)
   if(beg > 1 | end < ncol(x))  # avoid copy
     L <- L[beg:end,] 
 
@@ -115,18 +117,34 @@ association.test <- function(x, Y = x@ped$pheno, X = matrix(1, nrow(x)),
 }
 
 
-checkX <- function(X, mean.y) {
-  X1 <- cbind(1,X)
-  n <- ncol(X1)
-  a <- crossprod(X1)
-  b <- a[ 2:n, 2:n, drop = FALSE ]
-  det.b <- det(b)
-  if( is.na(det.b) ) stop("Covariates can't be NA")
-  if( abs(det.b) < 1e-4 ) stop("Covariate matrix is (quasi) singular")
-  if( abs(det(a)) > 1e-4 & mean.y > 1e-4) {
-    warning("An intercept column was added to the covariate matrix X")
-    return(X1)
+# Check AND replaces by QR decomposition...
+trans.X <- function(X, PCs = matrix(0, nrow=nrow(X), ncol=0), mean.y = 1) {
+  if(any(is.na(X)))
+    stop("Covariates can't be NA")
+
+  PCs <- as.matrix(PCs) # cas où p = 1
+  n.X  <- ncol(X)
+  n.pc <- ncol(PCs)
+  n <- n.X + n.pc
+
+  qr.X <- qr( cbind(PCs, X) );
+  if(qr.X$rank < n) {
+    warning("Covariate matrix X is not full rank, removing col(s) ", paste(qr.X$pivot[ seq(qr.X$rank+1,n) ] - n.pc , collapse = ", "))
+    X <- X[ , qr.X$pivot[seq(n.pc+1, qr.X$rank)] - n.pc]
+    qr.X <- qr(X)
   }
-  return(X)
+  if(mean.y > 1e-4) {
+    X1 <- cbind(1,X);
+    qr.X1 <- qr(X1);
+    if(qr.X1$rank == ncol(X1)) {
+      warning("An intercept column was added to the covariate matrix X")
+      X <- X1;
+      qr.X <- qr.X1
+    }
+  }
+  if( qr.X$rank == ncol(X) )
+    qr.Q(qr.X)
+  else
+    qr.Q(qr(X))
 }
 
