@@ -1,13 +1,10 @@
-// [[Rcpp::depends(RcppParallel)]]
 #include <Rcpp.h>
-#include <RcppParallel.h>
 #include <iostream>
 #include <ctime>
 #include "matrix4.h"
 #include "loubar.h"
 
 using namespace Rcpp;
-using namespace RcppParallel;
 
 /***********************************************************/
 
