@@ -1,12 +1,12 @@
 #include <Rcpp.h>
-#include <RcppParallel.h>
+#include "Parallel.h"
 #include <iostream>
 #include <ctime>
 #include "matrix4.h"
 #include "loubar.h"
 
 using namespace Rcpp;
-using namespace RcppParallel;
+using namespace Parallel;
 
 
 struct paraPro2_p : public Worker {
@@ -21,14 +21,14 @@ struct paraPro2_p : public Worker {
 
  //constructeur
   paraPro2_p(matrix4 & A, std::vector<double> p, size_t r, double * v) 
-            : A(A), p(p), ncol(A.ncol), true_ncol(A.true_ncol), v(v), r(r) {
+            : A(A), p(p), ncol(A.ncol), true_ncol(A.true_ncol), r(r), v(v) {
     vA = new double[r*ncol];
     std::fill(vA, vA+r*ncol, 0); 
   }
 
   //constructeur pour le split
   paraPro2_p(paraPro2_p & Q, Split) : A(Q.A), p(Q.p), ncol(Q.ncol),
-           true_ncol(Q.true_ncol), v(Q.v), r(Q.r) {
+           true_ncol(Q.true_ncol), r(Q.r), v(Q.v) {
     vA = new double[r*ncol];
     std::fill(vA, vA+r*ncol, 0);
   }
